# Security Policy

## Supported Versions

The following list shows the maintenance status of all versions.

| Version | Supported          | Available on [PyPI :link:][link-pypi] |
| ------- | ------------------ | ------------------------------------- |
| `0.1.x` | :white_check_mark: | :white_check_mark:                    |

## Reporting a Vulnerability

The vulnerability can be reported by submitting a [vulnerability issue :link:][link-issue].

Any reported vulnerability will be replied ASAP. Please follow the guidelines of the issue
template and let me know what to expect if the vulnerability is accepted or declined, etc.

Any vulnerability submitted for a not-supported version will be declined directly.

[link-pypi]:https://pypi.org/project/steam-editor-tools
[link-issue]:https://github.com/cainmagi/steam-editor-tools/security/advisories/new
